@@ -39,7 +39,7 @@ All classes inherit from :class:`github.GithubObject.GithubObject`.
 
 import logging
 
-from .MainClass import Github, GithubIntegration
+from github.MainClass import Github, GithubIntegration
 from .GithubException import GithubException, BadCredentialsException, UnknownObjectException, BadUserAgentException, RateLimitExceededException, BadAttributeException, TwoFactorException
 from .InputFileContent import InputFileContent
 from .InputGitAuthor import InputGitAuthor
