@@ -10,6 +10,7 @@
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
 # Copyright 2017 Balázs Rostás <rostas.balazs@gmail.com>                     #
 # Copyright 2017 Jannis Gebauer <ja.geb@me.com>                                #
+# Copyright 2018 Jacopo Notarstefano <jacopo.notarstefano@gmail.com>           #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
@@ -140,7 +141,8 @@ class AuthenticatedUser(Framework.TestCase):
 
     def testCreateRepositoryWithAllArguments(self):
         repo = self.user.create_repo(name="TestPyGithub", description="Repo created by PyGithub", homepage="http://foobar.com",
-                                     private=False, has_issues=False, has_wiki=False, has_downloads=False)
+                                     private=False, has_issues=False, has_projects=False, has_wiki=False, has_downloads=False,
+                                     allow_squash_merge=False, allow_merge_commit=False, allow_rebase_merge=True)
         self.assertEqual(repo.url, "https://api.github.com/repos/jacquev6/TestPyGithub")
 
     def testCreateRepositoryWithAutoInit(self):
